@@ -1,12 +1,12 @@
 """Class implementation for line color interface.
 """
 
-from typing import Union
 
 from apyscript.color import color_util
 from apyscript.expression import expression_file_util
 from apyscript.html import html_util
 from apyscript.type import String
+from apyscript.type import value_util
 from apyscript.type.variable_name_interface import VariableNameInterface
 
 
@@ -15,7 +15,7 @@ class LineColorInterface(VariableNameInterface):
     _line_color: String
 
     @property
-    def line_color(self) -> Union[str, String]:
+    def line_color(self) -> String:
         """
         Get this instance's line color.
 
@@ -25,10 +25,12 @@ class LineColorInterface(VariableNameInterface):
             Current line color (hexadecimal string, e.g., '#00aaff').
             If not be set, blank string will be returned.
         """
-        return self._line_color
+        self._initialize_line_color_if_not_initialized()
+        line_color: String = value_util.get_copy(value=self._line_color)
+        return line_color
 
     @line_color.setter
-    def line_color(self, value: Union[str, String]) -> None:
+    def line_color(self, value: String) -> None:
         """
         Update this instance's line color.
 
@@ -53,20 +55,25 @@ class LineColorInterface(VariableNameInterface):
             expression=expression)
 
     def update_line_color_and_skip_appending_exp(
-            self, value: Union[str, String]) -> None:
+            self, value: String) -> None:
         """
         Update line color and skip appending expression to file.
 
         Parameters
         ----------
-        value : str or String
+        value : String
             Line color to set.
         """
-        if isinstance(value, String):
-            value.value = color_util.complement_hex_color(
-                hex_color_code=value.value)
-        else:
-            value = color_util.complement_hex_color(
-                hex_color_code=value)
-            value = String(value)
+        value.value = color_util.complement_hex_color(
+            hex_color_code=value.value)
+        self._initialize_line_color_if_not_initialized()
         self._line_color = value
+
+    def _initialize_line_color_if_not_initialized(self) -> None:
+        """
+        Initialize line_color attribute if that value is not
+        initialized yet.
+        """
+        if hasattr(self, '_line_color'):
+            return
+        self._line_color = String('')
