@@ -788,3 +788,92 @@ class Array(CopyInterface):
             Converted value string.
         """
         return str(self._value)
+
+    def __repr__(self) -> str:
+        """
+        Get a representation string of this instance.
+
+        Returns
+        -------
+        repr_str : str
+            Representation string of this instance.
+        """
+        repr_str: str = (
+            f'Array({self._value})'
+        )
+        return repr_str
+
+    def index_of(self, value: Any) -> Int:
+        """
+        Search specified value's index and return it.
+
+        Parameters
+        ----------
+        value : *
+            Any value to search.
+
+        Returns
+        -------
+        index : Int
+            Found position of index. If value is not contains,
+            -1 will be returned.
+        """
+        index: Int = Int(-1)
+        try:
+            index_: int = self._value.index(value)
+        except Exception:
+            index_ = -1
+        index._value = index_
+        self._append_index_of_expression(index=index, value=value)
+        return index
+
+    def _append_index_of_expression(
+            self, index: Int, value: Any) -> None:
+        """
+        Append index_of method expression to file.
+
+        Parameters
+        ----------
+        index : Int
+            Found position of index. If value is not contains,
+            -1 will be set.
+        value : *
+            Any value to search.
+        """
+        value_str: str = value_util.get_value_str_for_expression(
+            value=value)
+        expression: str = (
+            f'{index.variable_name} = {self.variable_name}'
+            f'.indexOf({value_str});'
+        )
+        expression_file_util.wrap_by_script_tag_and_append_expression(
+            expression=expression)
+
+    def __eq__(self, other: Any) -> bool:
+        """
+        Equal comparison method.
+
+        Parameters
+        ----------
+        other : *
+            Other value to compare. list or Array types are acceptable.
+
+        Returns
+        -------
+        result : bool
+            Comparison result.
+        """
+        if isinstance(other, Array):
+            return self.value == other.value
+        return self.value == other
+
+    def __bool__(self) -> bool:
+        """
+        Get a boolean value whether this array is empty or not.
+
+        Returns
+        -------
+        result : bool
+            If this array is empty, True will be returned.
+        """
+        return bool(self._value)
